==> blesta-5.10.2.zip: blesta/plugins/system_overview/language/ro_ro/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.ro_ro
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.graph_line_name.canceled'] = 'Anulat';
$lang['AdminMain.graph_line_name.active'] = 'Activ';
$lang['AdminMain.graph_name.graph_clients'] = 'Clienți';
$lang['AdminMain.graph_line_name.new'] = 'Nou';
$lang['AdminMain.graph_line_name.suspended'] = 'Suspendat';
$lang['AdminMain.graph_name.graph_services'] = 'Servicii';
$lang['AdminMain.settings.submit_settings'] = 'Actualizarea setărilor';
$lang['AdminMain.settings.submit_cancel'] = 'Întoarcerea la Prezentare generală';
$lang['AdminMain.settings.date_range'] = 'Intervalul de date al graficului';
$lang['AdminMain.settings.show_legend'] = 'Arată legenda';
$lang['AdminMain.settings.tooltip_show_one_tab'] = 'Nu mai separă graficele în file, ci le afișează pe toate într-o singură filă.';
$lang['AdminMain.settings.show_one_tab'] = 'Afișați doar o singură filă';
$lang['AdminMain.settings.heading_settings'] = 'Setări';
$lang['AdminMain.settings.graph_services'] = 'Graficul serviciilor';
$lang['AdminMain.settings.text_graphs_services'] = 'Verificați ce grafice trebuie să apară în fila Servicii.';
$lang['AdminMain.settings.heading_services'] = 'Fila Servicii';
$lang['AdminMain.settings.graph_clients'] = 'Graficul clienților';
$lang['AdminMain.settings.text_graphs_clients'] = 'Verificați ce grafice trebuie să apară în fila Clienți.';
$lang['AdminMain.settings.heading_clients'] = 'fila Clienți';
$lang['AdminMain.settings.pending_orders'] = 'Comenzi în așteptare';
$lang['AdminMain.settings.open_tickets'] = 'Bilete deschise';
$lang['AdminMain.settings.recurring_invoices'] = 'Facturi recurente';
$lang['AdminMain.settings.active_users_today'] = 'Utilizatori activi astăzi';
$lang['AdminMain.settings.services_scheduled_cancellation'] = 'Servicii programate pentru anulare';
$lang['AdminMain.settings.services_active'] = 'Servicii active';
$lang['AdminMain.settings.clients_active'] = 'Clienți activi';
$lang['AdminMain.settings.text_options'] = 'Bifați opțiunile care vor apărea în prezentarea generală a sistemului.';
$lang['AdminMain.settings.heading_statistics'] = 'Statistici';
$lang['AdminMain.date_range.days'] = '%1$s Zile';
$lang['AdminMain.overview.tooltip_last_activity_minutes'] = '%1$s minute în urmă';
$lang['AdminMain.overview.tooltip_last_activity_minute'] = '1 minut în urmă';
$lang['AdminMain.overview.tooltip_last_activity_now'] = 'Chiar acum';
$lang['AdminMain.overview.tooltip_location'] = 'Locație';
$lang['AdminMain.overview.tooltip_activity'] = 'Ultima activitate';
$lang['AdminMain.overview.tab_services'] = 'Servicii';
$lang['AdminMain.overview.tab_clients'] = 'Clienți';
$lang['AdminMain.overview.tab_all'] = 'Grafice';
$lang['AdminMain.overview.heading_users'] = 'Utilizatori recenți';
$lang['AdminMain.overview.statistic.open_tickets'] = 'Bilete deschise';
$lang['AdminMain.overview.statistic.pending_orders'] = 'Comenzi în așteptare';
$lang['AdminMain.overview.statistic.recurring_invoices'] = 'Facturi recurente';
$lang['AdminMain.overview.statistic.active_users_today'] = 'Utilizatori activi astăzi';
$lang['AdminMain.overview.statistic.services_scheduled_cancellation'] = 'Servicii programate pentru anulare';
$lang['AdminMain.overview.statistic.services_active'] = 'Servicii active';
$lang['AdminMain.overview.statistic.clients_active'] = 'Clienți activi';
$lang['AdminMain.index.boxtitle_overview'] = 'Prezentare generală a sistemului';
$lang['AdminMain.!success.options_updated'] = 'Setările din System Overview au fost actualizate cu succes!';

==> blesta-5.11.4.zip: blesta/plugins/system_overview/language/ro_ro/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.ro_ro
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.graph_line_name.canceled'] = 'Anulat';
$lang['AdminMain.graph_line_name.active'] = 'Activ';
$lang['AdminMain.graph_name.graph_clients'] = 'Clienți';
$lang['AdminMain.graph_line_name.new'] = 'Nou';
$lang['AdminMain.graph_line_name.suspended'] = 'Suspendat';
$lang['AdminMain.graph_name.graph_services'] = 'Servicii';
$lang['AdminMain.settings.submit_settings'] = 'Actualizarea setărilor';
$lang['AdminMain.settings.submit_cancel'] = 'Întoarcerea la Prezentare generală';
$lang['AdminMain.settings.date_range'] = 'Intervalul de date al graficului';
$lang['AdminMain.settings.show_legend'] = 'Arată legenda';
$lang['AdminMain.settings.tooltip_show_one_tab'] = 'Nu mai separă graficele în file, ci le afișează pe toate într-o singură filă.';
$lang['AdminMain.settings.show_one_tab'] = 'Afișați doar o singură filă';
$lang['AdminMain.settings.heading_settings'] = 'Setări';
$lang['AdminMain.settings.graph_services'] = 'Graficul serviciilor';
$lang['AdminMain.settings.text_graphs_services'] = 'Verificați ce grafice trebuie să apară în fila Servicii.';
$lang['AdminMain.settings.heading_services'] = 'Fila Servicii';
$lang['AdminMain.settings.graph_clients'] = 'Graficul clienților';
$lang['AdminMain.settings.text_graphs_clients'] = 'Verificați ce grafice trebuie să apară în fila Clienți.';
$lang['AdminMain.settings.heading_clients'] = 'fila Clienți';
$lang['AdminMain.settings.pending_orders'] = 'Comenzi în așteptare';
$lang['AdminMain.settings.open_tickets'] = 'Bilete deschise';
$lang['AdminMain.settings.recurring_invoices'] = 'Facturi recurente';
$lang['AdminMain.settings.active_users_today'] = 'Utilizatori activi astăzi';
$lang['AdminMain.settings.services_scheduled_cancellation'] = 'Servicii programate pentru anulare';
$lang['AdminMain.settings.services_active'] = 'Servicii active';
$lang['AdminMain.settings.clients_active'] = 'Clienți activi';
$lang['AdminMain.settings.text_options'] = 'Bifați opțiunile care vor apărea în prezentarea generală a sistemului.';
$lang['AdminMain.settings.heading_statistics'] = 'Statistici';
$lang['AdminMain.date_range.days'] = '%1$s Zile';
$lang['AdminMain.overview.tooltip_last_activity_minutes'] = '%1$s minute în urmă';
$lang['AdminMain.overview.tooltip_last_activity_minute'] = '1 minut în urmă';
$lang['AdminMain.overview.tooltip_last_activity_now'] = 'Chiar acum';
$lang['AdminMain.overview.tooltip_location'] = 'Locație';
$lang['AdminMain.overview.tooltip_activity'] = 'Ultima activitate';
$lang['AdminMain.overview.tab_services'] = 'Servicii';
$lang['AdminMain.overview.tab_clients'] = 'Clienți';
$lang['AdminMain.overview.tab_all'] = 'Grafice';
$lang['AdminMain.overview.heading_users'] = 'Utilizatori recenți';
$lang['AdminMain.overview.statistic.open_tickets'] = 'Bilete deschise';
$lang['AdminMain.overview.statistic.pending_orders'] = 'Comenzi în așteptare';
$lang['AdminMain.overview.statistic.recurring_invoices'] = 'Facturi recurente';
$lang['AdminMain.overview.statistic.active_users_today'] = 'Utilizatori activi astăzi';
$lang['AdminMain.overview.statistic.services_scheduled_cancellation'] = 'Servicii programate pentru anulare';
$lang['AdminMain.overview.statistic.services_active'] = 'Servicii active';
$lang['AdminMain.overview.statistic.clients_active'] = 'Clienți activi';
$lang['AdminMain.index.boxtitle_overview'] = 'Prezentare generală a sistemului';
$lang['AdminMain.!success.options_updated'] = 'Setările din System Overview au fost actualizate cu succes!';
$lang['AdminMain.date_range.day'] = '1 zi';
$lang['AdminMain.date_range.month'] = 'Luna curentă';
$lang['AdminMain.date_range.ytd'] = 'An la zi';
